@@ -332,7 +332,7 @@ pub fn decrypt_combined(
     additional_data: Option<&[u8]>,
 ) -> anyhow::Result<Vec<u8>> {
     if bytes.is_empty() {
-        return Ok(vec![])
+        return Ok(vec![]);
     }
     anyhow::ensure!(
         bytes.len() > MAC_LENGTH,
@@ -377,7 +377,7 @@ pub fn decrypt_detached(
     additional_data: Option<&[u8]>,
 ) -> anyhow::Result<Vec<u8>> {
     if bytes.is_empty() {
-        return Ok(vec![])
+        return Ok(vec![]);
     }
     anyhow::ensure!(
         bytes.len() > MAC_LENGTH,
@@ -520,7 +520,7 @@ impl SymmetricCrypto for Aes256GcmCrypto {
         additional_data: Option<&[u8]>,
     ) -> anyhow::Result<Vec<u8>> {
         if bytes.is_empty() {
-            return Ok(vec![])
+            return Ok(vec![]);
         }
         if bytes.len() < MAC_LENGTH + MIN_DATA_LENGTH {
             anyhow::bail!("decryption failed - data too short");
